==> dartdoc-0.33.0.tar.gz: lib/templates/md/library.md <==
{{>head}}

{{#self}}
# {{{ name }}} {{ kind }}

{{>source_link}}
{{>categorization}}
{{>feature_set}}
{{/self}}

{{#library}}
{{>documentation}}
{{/library}}

{{#library.hasPublicClasses}}
## Classes

{{#library.publicClasses}}
{{>class}}

{{/library.publicClasses}}
{{/library.hasPublicClasses}}

{{#library.hasPublicMixins}}
## Mixins

{{#library.publicMixins}}
{{>mixin}}

{{/library.publicMixins}}
{{/library.hasPublicMixins}}

{{#library.hasPublicExtensions}}
## Extensions

{{#library.publicExtensions}}
{{>extension}}

{{/library.publicExtensions}}
{{/library.hasPublicExtensions}}

{{#library.hasPublicConstants}}
## Constants

{{#library.publicConstants}}
{{>constant}}

{{/library.publicConstants}}
{{/library.hasPublicConstants}}

{{#library.hasPublicProperties}}
## Properties

{{#library.publicProperties}}
{{>property}}

{{/library.publicProperties}}
{{/library.hasPublicProperties}}

{{#library.hasPublicFunctions}}
## Functions

{{#library.publicFunctions}}
{{>callable}}

{{/library.publicFunctions}}
{{/library.hasPublicFunctions}}

{{#library.hasPublicEnums}}
## Enums

{{#library.publicEnums}}
{{>class}}

{{/library.publicEnums}}
{{/library.hasPublicEnums}}

{{#library.hasPublicTypedefs}}
## Typedefs

{{#library.publicTypedefs}}
{{>callable}}

{{/library.publicTypedefs}}
{{/library.hasPublicTypedefs}}

{{#library.hasPublicExceptions}}
## Exceptions / Errors

{{#library.publicExceptions}}
{{>class}}

{{/library.publicExceptions}}
{{/library.hasPublicExceptions}}

{{>footer}}

==> dartdoc-0.39.0.tar.gz: lib/templates/md/library.md <==
{{>head}}

{{#self}}
# {{{ name }}} {{ kind }}

{{>source_link}}
{{>categorization}}
{{>feature_set}}
{{/self}}

{{#library}}
{{>documentation}}
{{/library}}

{{#library.hasPublicClasses}}
## Classes

{{#library.publicClassesSorted}}
{{>class}}

{{/library.publicClassesSorted}}
{{/library.hasPublicClasses}}

{{#library.hasPublicMixins}}
## Mixins

{{#library.publicMixinsSorted}}
{{>mixin}}

{{/library.publicMixinsSorted}}
{{/library.hasPublicMixins}}

{{#library.hasPublicExtensions}}
## Extensions

{{#library.publicExtensionsSorted}}
{{>extension}}

{{/library.publicExtensionsSorted}}
{{/library.hasPublicExtensions}}

{{#library.hasPublicConstants}}
## Constants

{{#library.publicConstantsSorted}}
{{>constant}}

{{/library.publicConstantsSorted}}
{{/library.hasPublicConstants}}

{{#library.hasPublicProperties}}
## Properties

{{#library.publicPropertiesSorted}}
{{>property}}

{{/library.publicPropertiesSorted}}
{{/library.hasPublicProperties}}

{{#library.hasPublicFunctions}}
## Functions

{{#library.publicFunctionsSorted}}
{{>callable}}

{{/library.publicFunctionsSorted}}
{{/library.hasPublicFunctions}}

{{#library.hasPublicEnums}}
## Enums

{{#library.publicEnumsSorted}}
{{>class}}

{{/library.publicEnumsSorted}}
{{/library.hasPublicEnums}}

{{#library.hasPublicTypedefs}}
## Typedefs

{{#library.publicTypedefsSorted}}
{{>callable}}

{{/library.publicTypedefsSorted}}
{{/library.hasPublicTypedefs}}

{{#library.hasPublicExceptions}}
## Exceptions / Errors

{{#library.publicExceptionsSorted}}
{{>class}}

{{/library.publicExceptionsSorted}}
{{/library.hasPublicExceptions}}

{{>footer}}
